@@ -1,17 +1,17 @@
 
 
 setMethod("window<-", signature(x="SpatRaster"), 
-	function(x, ..., value)  {
+	function(x, value)  {
 		if (inherits(value, "SpatExtent")) {
 			value <- value * ext(x)
 			if (!(x@ptr$setWindow(value@ptr))) {
 				error("window<-,SpatRaster", "could not set window")
 			}
-			warn("window<-", "using a window is experimental")
-		} else if (is.null(value	)) {
+			#warn("window<-", "using a window is experimental")
+		} else if (is.null(value) || is.na(value)) {
 			x@ptr$removeWindow()
 		} else {
-			error("window<-,SpatRaster", "'value' should be a SpatExtent or NULL")
+			error("window<-", "'value' should be a SpatExtent, NULL or NA")
 		}
 		x
 	}
@@ -19,7 +19,7 @@ setMethod("window<-", signature(x="SpatRaster"),
 
 
 setMethod("window", signature(x="SpatRaster"), 
-	function(x, ...)  {
+	function(x)  {
 		x@ptr$hasWindow()
 	}
 )
