@@ -163,6 +163,7 @@ RCPP_MODULE(spat){
 		.method("deepcopy", &SpatOptions::deepCopy, "deepCopy")
 		.property("tempdir", &SpatOptions::get_tempdir, &SpatOptions::set_tempdir )
 		.property("memfrac", &SpatOptions::get_memfrac, &SpatOptions::set_memfrac )
+		.property("tolerance", &SpatOptions::get_tolerance, &SpatOptions::set_tolerance )
 		.property("filenames", &SpatOptions::get_filenames, &SpatOptions::set_filenames )
 		.property("filetype", &SpatOptions::get_filetype, &SpatOptions::set_filetype )
 		.property("datatype", &SpatOptions::get_datatype, &SpatOptions::set_datatype )
@@ -404,7 +405,7 @@ RCPP_MODULE(spat){
     class_<SpatRaster>("SpatRaster")
 		.constructor()
 	 // .constructor<std::string, int>()
-	    .constructor<std::vector<std::string>, std::vector<int>, std::vector<std::string>, bool, std::vector<size_t>>()
+	    .constructor<std::vector<std::string>, std::vector<int>, std::vector<std::string>, bool, std::vector<std::string>, std::vector<size_t>>()
 		.constructor<std::vector<unsigned>, std::vector<double>, std::string>()
 
 		.method("fromFiles", &SpatRaster::fromFiles)
@@ -606,8 +607,8 @@ RCPP_MODULE(spat){
 		.method("extractVector", &SpatRaster::extractVector, "extractVector")
 		.method("extractVectorFlat", &SpatRaster::extractVectorFlat, "extractVectorFlat")
 		.method("flip", &SpatRaster::flip, "flip")
-		.method("focal1", &SpatRaster::focal1, "focal1")
-		.method("focal2", &SpatRaster::focal2, "focal2")
+//		.method("focal1", &SpatRaster::focal1, "focal1")
+//		.method("focal2", &SpatRaster::focal2, "focal2")
 		.method("focal3", &SpatRaster::focal3, "focal3")
 		.method("focalValues", &SpatRaster::focal_values, "focalValues")
 		.method("count", &SpatRaster::count, "count")
@@ -641,7 +642,9 @@ RCPP_MODULE(spat){
 		.method("rotate", &SpatRaster::rotate, "rotate")
 		//.method("sampleCells", &SpatRaster::sampleCells, "sampleCells")
 		.method("sampleRegularRaster", &SpatRaster::sampleRegularRaster, "sampleRegular")
+		.method("sampleRowColRaster", &SpatRaster::sampleRowColRaster, "sampleRowCol")
 		.method("sampleRegularValues", &SpatRaster::sampleRegularValues, "sampleValues")
+		.method("sampleRowColValues", &SpatRaster::sampleRowColValues, "sampleRowCol")
 		.method("sampleRandomRaster", &SpatRaster::sampleRandomRaster, "sampleRandom")
 		.method("sampleRandomValues", &SpatRaster::sampleRandomValues, "sampleValues")
 		.method("scale", &SpatRaster::scale, "scale")
