@@ -24,8 +24,8 @@ class SpatRasterCollection {
 		SpatMessages msg;
 		void setError(std::string s) { msg.setError(s); }
 		void addWarning(std::string s) { msg.addWarning(s); }
-		bool hasError() { return msg.has_error; }
-		bool hasWarning() { return msg.has_warning; }
+		bool has_error() { return msg.has_error; }
+		bool has_warning() { return msg.has_warning; }
 		std::string getWarnings() { return msg.getWarnings(); }
 		std::string getError() { return msg.getError(); }
 	
